SlickGrid plugin example: AutoTooltips

| ## Demonstrates: AutoTooltips plugin Optional stylable jQueryUI tooltips. ## Instructions: Resize the columns until see ellipsis in column or header. Hover over cell to see tooltip. For jQueryUI tooltips, call the .tooltips() function on the document to convert all tooltips to jQueryUI. To style jQueryUI tooltips, use the generic jQueryUI class 'ui-tooltip', or pass in a class name as an option. ## Usage:
    plugin = new Slick.AutoTooltips(pluginOptions);
    grid.registerPlugin(plugin);
    grid.render();
jQueryUI Tooltips:
    $( document ).tooltip( { tooltipClass: "my-tooltip-class" } );
## View Source: View the source for this example on Github